.. examples:

========
Examples
========

Flow Duration Curve Examples
----------------------------

.. toctree::
    :maxdepth: 2

    flow_duration_curve_examples

Raster Hydrograph Examples
--------------------------

.. toctree::
    :maxdepth: 2

    raster_hydrograph_examples

Streamflow Duration Hydrograph Examples
---------------------------------------

.. toctree::
    :maxdepth: 2

    streamflow_duration_hydrograph_examples

Cumulative Hydrograph Examples
------------------------------

.. toctree::
    :maxdepth: 2

    cumulative_hydrograph_examples

Percentile Calculation Examples
-------------------------------

.. toctree::
    :maxdepth: 2

    percentile_calculation_examples

Similarity Examples
-------------------

.. toctree::
    :maxdepth: 2

    similarity_examples
